'use client'
import SendFile from "@/feature/messenger/components/ui/buttons/SendFile";
import useConfigChatStore from "@/feature/messenger/store/chat_store/useConfigChatStore";
import { Button, Dropdown, DropdownItem, DropdownMenu, DropdownTrigger, Tooltip } from "@nextui-org/react";
import { Calendar, Image, Paperclip, Plus, User } from "react-feather";
import { useState, useEffect } from "react";
import useHandleConversationStore from "@/feature/messenger/store/useHandleConversationStore";
import { useTranslation } from "@/hooks/useTranslation";
import useResponsiveBtn from "@/feature/messenger/hooks/useReponsiveBtn";

export default function OptionsButton() {
    // permisos Opciones
    const agentPermissions = useConfigChatStore(state => state.permisions);
    const [components, setComponents] = useState<JSX.Element[]>([]);
    const handleOpenModalGallery = useHandleConversationStore(state => state.actions.handleOpenModalGallery);
    const handleOpenModalEditContact = useHandleConversationStore(state => state.actions.handleOpenModalEditContact);
    const handleOpenModalFollowUp = useHandleConversationStore(state => state.actions.handleOpenModalFollowUp);
    const { trans } = useTranslation();
    const { responsiveButtonFooter, responsiveIconButtonFooter } = useResponsiveBtn();

    useEffect(() => {
        const componentOptions = () => {
            const componentsArray = [];

            if (agentPermissions.calendar) {
                componentsArray.push(
                    <DropdownItem
                        key="Seguimiento"
                        startContent={<Calendar size={20} />}
                        onClick={() => handleOpenModalFollowUp()}
                    >
                        Seguimiento
                    </DropdownItem>
                );
            }

            if (agentPermissions.biblioteca) {
                componentsArray.push(
                    <DropdownItem
                        key="Galeria"
                        startContent={<Image size={20} />}
                        onClick={() => handleOpenModalGallery()}
                    >
                        Galeria
                    </DropdownItem>
                );
            }

            if (agentPermissions.crea_agenda) {
                componentsArray.push(
                    <DropdownItem
                        key="Agenda"
                        startContent={<User size={20} />}
                        onClick={() => handleOpenModalEditContact()}
                    >
                        Agenda
                    </DropdownItem>
                );
            }

            if (agentPermissions.adjuntar_archivos) {
                componentsArray.push(
                    <DropdownItem
                        key="archivo"
                        startContent={<Paperclip size={20} />}
                    >
                        <SendFile />
                    </DropdownItem>
                );
            }

            return componentsArray;
        };

        setComponents(componentOptions());
    }, [agentPermissions]);

    return (
        (agentPermissions.crea_agenda || agentPermissions.adjuntar_archivos || agentPermissions.biblioteca || agentPermissions.calendar) ? (
        <Dropdown placement="top" className={`${components.length === 0 ? "hidden" : "block"}`}>
            <Tooltip
                placement="top"
                content={trans('footer_content_chat_options_title')}	
                color="default"
            >
                <div>
                    <DropdownTrigger>
                        <Button color="primary" radius="full" className={responsiveButtonFooter} variant="flat">
                            <Plus size={14} className={responsiveIconButtonFooter} />
                        </Button>
                    </DropdownTrigger>
                </div>
            </Tooltip>
            <DropdownMenu aria-label="Dynamic Actions">
                {components}
            </DropdownMenu>
            </Dropdown>
        ) : null
    )
}
